Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Cognito Sync.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for Amazon Cognito Sync - AWS Identity and Access Management
Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for Amazon Cognito Sync

Amazon Cognito Sync (service prefix: `cognito-sync` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon Cognito Sync
- Resource Types Defined by Amazon Cognito Sync
- Condition Keys for Amazon Cognito Sync

## Actions Defined by Amazon Cognito Sync

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
BulkPublish | Initiates a bulk publish of all existing datasets for an Identity Pool to the configured stream. | Write | identitypool* |  |
DeleteDataset | Deletes the specific dataset. | Write | dataset* |  |
DescribeDataset | Gets meta data about a dataset by identity and dataset name. | Read | dataset* |  |
DescribeIdentityPoolUsage | Gets usage details (for example, data storage) about a particular identity pool. | Read | identitypool* |  |
DescribeIdentityUsage | Gets usage information for an identity, including number of datasets and data usage. | Read | identity* |  |
GetBulkPublishDetails | Get the status of the last BulkPublish operation for an identity pool. | Read | identitypool* |  |
GetCognitoEvents | Gets the events and the corresponding Lambda functions associated with an identity pool. | Read | identitypool* |  |
GetIdentityPoolConfiguration | Gets the configuration settings of an identity pool. | Read | identitypool* |  |
ListDatasets | Lists datasets for an identity. | List | dataset* |  |
ListIdentityPoolUsage | Gets a list of identity pools registered with Cognito. | Read | identitypool* |  |
ListRecords | Gets paginated records, optionally changed after a particular sync count for a dataset and identity. | Read | dataset* |  |
QueryRecords [permission only] | A permission that grants the ability to query records. | Read |  |  |
RegisterDevice | Registers a device to receive push sync notifications. | Write | identity* |  |
SetCognitoEvents | Sets the AWS Lambda function for a given event type for an identity pool. | Write | identitypool* |  |
SetDatasetConfiguration [permission only] | A permission that grants ability to configure datasets. | Write | dataset* |  |
SetIdentityPoolConfiguration | Sets the necessary configuration for push sync. | Write | identitypool* |  |
SubscribeToDataset | Subscribes to receive notifications when a dataset is modified by another device. | Write | dataset* |  |
UnsubscribeFromDataset | Unsubscribes from receiving notifications when a dataset is modified by another device. | Write | dataset* |  |
UpdateRecords | Posts updates to records and adds and deletes records for a dataset and user. | Write | dataset* |  |

## Resource Types Defined by Amazon Cognito Sync

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
dataset | `arn:$ { Partition}:cognito-sync:$ { Region}:$ { Account}:identitypool/$ { IdentityPoolId}/identity/$ { IdentityId}/dataset/$ { DatasetName}` |
identity | `arn:$ { Partition}:cognito-sync:$ { Region}:$ { Account}:identitypool/$ { IdentityPoolId}/identity/$ { IdentityId}` |
identitypool | `arn:$ { Partition}:cognito-sync:$ { Region}:$ { Account}:identitypool/$ { IdentityPoolId}` |

## Condition Keys for Amazon Cognito Sync

Cognito Sync has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference .